package com.ruoyi.tcZz.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcZcdwpm;
import com.ruoyi.tcZz.service.ITcZcdwpmService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 众测单位排名(tc_zcdwpm)表控制层
 * @author du
 * @since 2024/8/5 13:16
 */
@RestController
@Api(tags = "众测单位排名")
@RequestMapping("/tcZz/networkSecurity/zcdwpm")
public class TcZcdwpmController extends BaseController {

    @Autowired
    private ITcZcdwpmService tcZcdwpmService;

    /**
     * 查询众测单位排名列表
     */
    @ApiOperation(value = "查询众测单位排名列表", response = TcZcdwpm.class)
    @GetMapping("/list")
    public TableDataInfo list(TcZcdwpm tc) {
        startPage();
        List<TcZcdwpm> list = tcZcdwpmService.page(tc);
        return getDataTable(list);
    }

    /**
     * 导出众测单位排名列表
     */
    @ApiOperation(value = " 导出众测单位排名列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZcdwpm tc) {
        List<TcZcdwpm> list = tcZcdwpmService.page(tc);
        ExcelUtil<TcZcdwpm> util = new ExcelUtil<>(TcZcdwpm.class);
        util.exportExcel(response, list, "众测单位排名详情数据");
    }

    /**
     * 获取众测单位排名信息
     */
    @ApiOperation(value = " 获取众测单位排名信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcZcdwpmService.getById(id));
    }

    /**
     * 新增众测单位排名
     */
    @ApiOperation(value = "新增众测单位排名")
    @PostMapping
    public AjaxResult add(@RequestBody TcZcdwpm tc) {
        return toAjax(tcZcdwpmService.insert(tc));
    }

    /**
     * 修改众测单位排名
     */
    @ApiOperation(value = "修改众测单位排名")
    @PutMapping
    public AjaxResult edit(@RequestBody TcZcdwpm tc) {
        return toAjax(tcZcdwpmService.update(tc));
    }

    /**
     * 删除众测单位排名
     */
    @ApiOperation(value = "删除众测单位排名")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcZcdwpmService.deleteByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcZcdwpm> util = new ExcelUtil<>(TcZcdwpm.class);
        List<TcZcdwpm> tcZbxqList = util.importExcel(file.getInputStream());
        tcZcdwpmService.importUser(tcZbxqList);
        return AjaxResult.success();
    }


    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response) {
        ExcelUtil<TcZcdwpm> util = new ExcelUtil<>(TcZcdwpm.class);
        util.importTemplateExcel(response, "众测单位排名详情");
    }
}
