package com.ruoyi.tcZz.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcZczccg;
import com.ruoyi.tcZz.service.ITcZczccgService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 众测资产成果(tc_zczccg)表控制层
 * @author du
 * @since 2024/8/5 13:16
 */
@RestController
@Api(tags = "众测资产成果")
@RequestMapping("/tcZz/networkSecurity/zczccg")
public class TcZczccgController extends BaseController {
    @Autowired
    private ITcZczccgService tcZczccgService;

    /**
     * 查询众测资产成果列表
     */
    @ApiOperation(value = "查询众测资产成果列表", response = TcZczccg.class)
    @GetMapping("/list")
    public TableDataInfo list(TcZczccg tc) {
        startPage();
        List<TcZczccg> list = tcZczccgService.page(tc);
        return getDataTable(list);
    }

    /**
     * 大屏查询众测资产成果最新一条
     */
    @ApiOperation(value = "大屏查询众测资产成果最新一条", response = TcZczccg.class)
    @GetMapping("/getOne")
    public AjaxResult getOne() {
        return success(tcZczccgService.getOne());
    }

    /**
     * 导出众测资产成果列表
     */
    @ApiOperation(value = " 导出众测资产成果列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZczccg tc) {
        List<TcZczccg> list = tcZczccgService.page(tc);
        ExcelUtil<TcZczccg> util = new ExcelUtil<>(TcZczccg.class);
        util.exportExcel(response, list, "众测资产成果详情数据");
    }

    /**
     * 获取众测资产成果信息
     */
    @ApiOperation(value = " 获取众测资产成果信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcZczccgService.getById(id));
    }

    /**
     * 新增众测资产成果
     */
    @ApiOperation(value = "新增众测资产成果")
    @PostMapping
    public AjaxResult add(@RequestBody TcZczccg tc) {
        return toAjax(tcZczccgService.insert(tc));
    }

    /**
     * 修改众测资产成果
     */
    @ApiOperation(value = "修改众测资产成果")
    @PutMapping
    public AjaxResult edit(@RequestBody TcZczccg tc) {
        return toAjax(tcZczccgService.update(tc));
    }

    /**
     * 删除众测资产成果
     */
    @ApiOperation(value = "删除众测资产成果")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcZczccgService.deleteByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcZczccg> util = new ExcelUtil<>(TcZczccg.class);
        List<TcZczccg> tcZbxqList = util.importExcel(file.getInputStream());
        tcZczccgService.importUser(tcZbxqList);
        return AjaxResult.success();
    }


    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response) {
        ExcelUtil<TcZczccg> util = new ExcelUtil<>(TcZczccg.class);
        util.importTemplateExcel(response, "众测资产成果详情");
    }
    
}
