package com.ruoyi.tcZz.utils;

import lombok.extern.slf4j.Slf4j;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang3.StringUtils;
import org.jasypt.util.text.BasicTextEncryptor;
import sun.misc.BASE64Decoder;
import sun.misc.BASE64Encoder;

import javax.crypto.Cipher;
import javax.crypto.Mac;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;
import java.io.*;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.security.DigestInputStream;
import java.security.Key;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.Base64;

@Slf4j
public class SecretUtil {

    public static final String TYPE_AES = "aes";
    public static final String TYPE_DES = "des";
    public static final String HMAC_MD5 = "HmacMD5";
    public static final String HMAC_SHA1 = "HmacSha1";

    private SecretUtil() {
    }

    /**
     * 将字符串进行 sha1 摘要
     *
     * @param str
     * @return
     * @throws Exception
     */
    public static String digestSha1(String str) {
        try {
            MessageDigest md = MessageDigest.getInstance("sha1");//md5
            md.update(str.getBytes());
            return toHexString(md.digest());
        } catch (Exception e) {
            log.warn("字符串加密失败 {}", e.getMessage(), e);
            return "";
        }
    }


    /**
     * 将字符串进行 sha1 摘要
     *
     * @param str
     * @return
     * @throws Exception
     */
    public static String digestSha256(String str) {
        try {
            MessageDigest md = MessageDigest.getInstance("sha256");//md5
            md.update(str.getBytes());
            return toHexString(md.digest());
        } catch (Exception e) {
            log.warn("字符串加密失败 {}", e.getMessage(), e);
            return "";
        }
    }

    /**
     * 将字符串进行 md5 摘要
     *
     * @param str
     * @return
     * @throws Exception
     */
    public static String digestMd5(String str) throws Exception {
        MessageDigest md = MessageDigest.getInstance("md5");//md5
        md.update(str.getBytes(StandardCharsets.UTF_8));
        return toHexString(md.digest());
    }

    /**
     * 将文件进�?sha1 摘要
     *
     * @param file
     * @return
     * @throws Exception
     */
    public static String digestFile(File file) throws Exception {
        InputStream is = null;
        DigestInputStream dis = null;
        MessageDigest md = MessageDigest.getInstance("sha1");//md5
        try {
            is = Files.newInputStream(file.toPath());
            dis = new DigestInputStream(is, md);
            byte[] buf = new byte[1024];
            //即使不用，也�?��将该流读�?��
            while (dis.read(buf) != -1) {
            }
        } finally {
            IOUtils.closeQuietly(dis);
            IOUtils.closeQuietly(is);
        }
        return toHexString(md.digest());
    }

    /**
     * 将文件进行摘要算法
     *
     * @param file
     * @param algorithm
     * @return
     * @throws Exception
     */
    public static String digestFile(File file,String algorithm) {
        InputStream is = null;

        try {
            MessageDigest md = MessageDigest.getInstance(algorithm);//md5
            is = Files.newInputStream(file.toPath());
            byte[] buf = new byte[1024];
            int numRead = 0;
            while ((numRead = is.read(buf)) > 0) {
                md.update(buf,0,numRead);
            }
            return toHexString(md.digest());
        } catch (NoSuchAlgorithmException | IOException e) {
            e.printStackTrace();
        } finally {
            IOUtils.closeQuietly(is);
        }
        return null;
    }

    /**
     * 使用jasypt加密
     *
     * @param content
     * @param key
     * @return
     * @throws Exception
     */
    public static String jasyptSymmetry(String content, String key) throws Exception {
        BasicTextEncryptor enc = new BasicTextEncryptor();
        enc.setPassword(key);
        return enc.encrypt(content);
    }

    /**
     * 使用jasypt解密
     *
     * @param content
     * @param key
     * @return
     * @throws Exception
     */
    public static String jasyptDecrypt(String content, String key) {
        log.info("content:{}, key:{}", content, key );
        BasicTextEncryptor enc = new BasicTextEncryptor();
        enc.setPassword(key);
        return enc.decrypt(content);
    }

    /**
     * 对称加密
     *
     * @param type
     * @param content
     * @param keys
     * @return
     * @throws Exception
     */
    public static byte[] symmetryEncrypt(String type, byte[] content, byte[] keys) throws Exception {
        Cipher encryptCipher = Cipher.getInstance(type);
        encryptCipher.init(Cipher.ENCRYPT_MODE, getKey(keys, type));
        return encryptCipher.doFinal(content);
    }

    /**
     * 对称解密
     *
     * @param type    可�?值为常量：TYPE_...
     * @param content
     * @param keys
     * @return
     * @throws Exception
     */
    public static byte[] decryptEncrypt(String type, byte[] content, byte[] keys) throws Exception {
        Cipher decryptCipher = Cipher.getInstance(type);
        decryptCipher.init(Cipher.DECRYPT_MODE, getKey(keys, type));
        return decryptCipher.doFinal(content);
    }

    /**
     * HMAC加密
     *
     * @param type    可�?值为常量：HMAC_....
     * @param content
     * @param keys
     * @return
     * @throws Exception
     */
    public static String encryptHMAC(String type, byte[] content, byte[] keys) throws Exception {
        SecretKey secretKey = new SecretKeySpec(keys, type);
        Mac mac = Mac.getInstance(secretKey.getAlgorithm());
        mac.init(secretKey);
        return toHexString(mac.doFinal(content));
    }

    /*
     * 根据指定的密钥字符串(密码)生成密钥，所�?es长度�?位，aes长度�?6位，不足�?，超出只取前面的
     * @param keyStr
     * @return
     */
    private static Key getKey(byte[] keyBytes, String type) {
        int len = "des".equalsIgnoreCase(type) ? 8 : 16;
        byte[] array = new byte[len];
        System.arraycopy(keyBytes, 0, array, 0, Math.min(keyBytes.length, len));
        return new SecretKeySpec(array, type);
    }

    /*
     * 把  byte[] 转换成16进制字符串
     * @param pb
     * @return
     */
    private static String toHexString(byte[] pb) {
        StringBuilder sb = new StringBuilder();
        for (byte b : pb) {
            int val = b & 0xff;
            if (val < 0x10) {
                sb.append('0');
            }
            sb.append(Integer.toHexString(val));
        }
        return sb.toString();
    }

    public static String bytesToBase64(byte[] bArray) {
        if (bArray == null) {
            return "";
        }
        return new BASE64Encoder().encode(bArray);
    }

    public static byte[] base64ToBytes(String str) throws IOException {
        BASE64Decoder decoder = new BASE64Decoder();
        return decoder.decodeBuffer(str);
    }

    public static byte[] decode(String str) throws Exception {
        byte[] bytes = null;
        BASE64Decoder decoder = new BASE64Decoder();
        bytes = decoder.decodeBuffer(str);
        return bytes;
    }

    public static String encode(byte[] bytes) {
        BASE64Encoder encoder = new BASE64Encoder();
        return encoder.encode(bytes);
    }

    public static String aes_128_cfb(String key,String content) throws Exception {
        key = StringUtils.isBlank(key) ? "a94a8fe5ccb19ba6" : key;
        SecretKey secretKey = new SecretKeySpec(key.getBytes(StandardCharsets.UTF_8), "AES");
        Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");
        cipher.init(Cipher.ENCRYPT_MODE, secretKey);
        return Base64.getEncoder().encodeToString(cipher.doFinal(content.getBytes(StandardCharsets.UTF_8)));
    }

    public static void main(String[] argc) {
        System.out.println(SecretUtil.digestSha1("iS%4Rh37g3"));
    }

}
